@@ -3,18 +3,18 @@ package segments
 import (
 	"testing"
 
-	"github.com/jandedobbeleer/oh-my-posh/src/mock"
-	"github.com/jandedobbeleer/oh-my-posh/src/platform"
 	"github.com/jandedobbeleer/oh-my-posh/src/properties"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
+	"github.com/jandedobbeleer/oh-my-posh/src/runtime/mock"
 
 	"github.com/stretchr/testify/assert"
 )
 
 func TestWriteCurrentShell(t *testing.T) {
 	expected := "zsh"
-	env := new(mock.MockedEnvironment)
+	env := new(mock.Environment)
 	env.On("Shell").Return(expected, nil)
-	env.On("Flags").Return(&platform.Flags{ShellVersion: "1.2.3"})
+	env.On("Flags").Return(&runtime.Flags{ShellVersion: "1.2.3"})
 	s := &Shell{
 		env:   env,
 		props: properties.Map{},
@@ -33,9 +33,9 @@ func TestUseMappedShellNames(t *testing.T) {
 		{Shell: "PWSH", Expected: "PS"},
 	}
 	for _, tc := range cases {
-		env := new(mock.MockedEnvironment)
+		env := new(mock.Environment)
 		env.On("Shell").Return(tc.Expected, nil)
-		env.On("Flags").Return(&platform.Flags{ShellVersion: "1.2.3"})
+		env.On("Flags").Return(&runtime.Flags{ShellVersion: "1.2.3"})
 		s := &Shell{
 			env: env,
 			props: properties.Map{
